     ;use Acme::emcA esu;
                              
;"n\1..1" tnirpprint "1..1\n";
;"n\1 ko" tnirpprint "ok 1\n";
                              
;"n\1 ko" tnirpprint "ok 1\n";
;"n\1..1" tnirpprint "1..1\n";
                              
     ;use Acme::emcA esu;
